@@ -33,7 +33,7 @@ const Utils = imports.utils;
 
 let _tileService = null;
 let _attributionImage = null;
- 
+
 const _TILE_SERVICE_URL = 'https://gis.gnome.org/services/v1/service.json';
 const _DEFAULT_SERVICE_FILE = 'maps-service.json';
 
@@ -87,23 +87,8 @@ function _updateAttributionImage(source) {
     _attributionImage.pixbuf = GdkPixbuf.Pixbuf.new_from_stream(stream, null);
  }
 
-function _readFile(filename)
-{
-    let status, buffer;
-    let file = Gio.File.new_for_path(filename);
-    try {
-        [status, buffer] = file.load_contents(null);
-    } catch (e) {
-        return null;
-    }
-    if (status)
-        return buffer;
-    else
-        return null;
-}
-
 function _getServiceFromFile(filename) {
-    let data = _readFile(filename);
+    let data = Utils.readFile(filename);
     if (!data) {
         log('Failed to open service file: ' + filename);
         System.exit(1);
@@ -145,8 +130,8 @@ function _getTileService() {
         Utils.debug(e);
         return _createDefaultService();
     }
- }
- 
+}
+
 function _createTileSource(source) {
     let tileSource = new Champlain.NetworkTileSource({
         id: source.id,
